@@ -3,7 +3,12 @@
 TRADER_TOKEN = -1
 WORLD_QUEST_ITEMLEVELS = [
     144,
+    148,
+    161,
+    171,
+    200,
 ]  # guess
+CALLINGS = WORLD_QUEST_ITEMLEVELS
 
 DUNGEON_NORMAL = 158
 DUNGEON_HEROIC = 171
